You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@mina.apache.org by ed...@apache.org on 2008/08/27 02:29:26 UTC

svn commit: r689301 - in /mina/trunk/example/src/test/java/org/apache/mina/example/proxy/telnet: ProxyTelnetTest.java ProxyTelnetTestClient.java

Author: edeoliveira
Date: Tue Aug 26 17:29:26 2008
New Revision: 689301

URL: http://svn.apache.org/viewvc?rev=689301&view=rev
Log:
Fixed name for surefire maven plugin compliance

Added:
    mina/trunk/example/src/test/java/org/apache/mina/example/proxy/telnet/ProxyTelnetTestClient.java   (contents, props changed)
      - copied, changed from r687202, mina/trunk/example/src/test/java/org/apache/mina/example/proxy/telnet/ProxyTelnetTest.java
Removed:
    mina/trunk/example/src/test/java/org/apache/mina/example/proxy/telnet/ProxyTelnetTest.java

Copied: mina/trunk/example/src/test/java/org/apache/mina/example/proxy/telnet/ProxyTelnetTestClient.java (from r687202, mina/trunk/example/src/test/java/org/apache/mina/example/proxy/telnet/ProxyTelnetTest.java)
URL: http://svn.apache.org/viewvc/mina/trunk/example/src/test/java/org/apache/mina/example/proxy/telnet/ProxyTelnetTestClient.java?p2=mina/trunk/example/src/test/java/org/apache/mina/example/proxy/telnet/ProxyTelnetTestClient.java&p1=mina/trunk/example/src/test/java/org/apache/mina/example/proxy/telnet/ProxyTelnetTest.java&r1=687202&r2=689301&rev=689301&view=diff
==============================================================================
--- mina/trunk/example/src/test/java/org/apache/mina/example/proxy/telnet/ProxyTelnetTest.java (original)
+++ mina/trunk/example/src/test/java/org/apache/mina/example/proxy/telnet/ProxyTelnetTestClient.java Tue Aug 26 17:29:26 2008
@@ -36,7 +36,7 @@
 import org.apache.mina.transport.socket.nio.NioSocketConnector;
 
 /**
  * ProxyTelnetTest.java - Tests a classical text communication through a proxy.
  * Changing the params and request type will allow to test the multiple options
  * (http or socks proxying, various authentications methods, ...).
  * 
@@ -44,7 +44,7 @@
  * @version $Rev$, $Date$
  * @since MINA 2.0.0-M3
  */
-public class ProxyTelnetTest {
+public class ProxyTelnetTestClient {
     
     /**
      * The user login used to authenticate with the proxy.
@@ -75,7 +75,7 @@
      * 
      * @throws Exception
      */
-    public ProxyTelnetTest() throws Exception {
+    public ProxyTelnetTestClient() throws Exception {
         // Create proxy connector.
         NioSocketConnector targetConnector = new NioSocketConnector(Runtime
                 .getRuntime().availableProcessors() + 1);
@@ -131,6 +131,6 @@
      * {@inheritDoc}
      */
     public static void main(String[] args) throws Exception {
-        new ProxyTelnetTest();
+        new ProxyTelnetTestClient();
     }
 }
\ No newline at end of file

Propchange: mina/trunk/example/src/test/java/org/apache/mina/example/proxy/telnet/ProxyTelnetTestClient.java
------------------------------------------------------------------------------
    svn:eol-style = native

Propchange: mina/trunk/example/src/test/java/org/apache/mina/example/proxy/telnet/ProxyTelnetTestClient.java
------------------------------------------------------------------------------
    svn:mergeinfo = 

Propchange: mina/trunk/example/src/test/java/org/apache/mina/example/proxy/telnet/ProxyTelnetTestClient.java
------------------------------------------------------------------------------
    svn:mime-type = text/plain
@@ -36,7 +36,7 @@
 
 /**
- * ProxyTelnetTest.java - Tests a classical text communication through a proxy.
+ * ProxyTelnetTestClient.java - Tests a classical text communication through a proxy.
  * Changing the params and request type will allow to test the multiple options
  * (http or socks proxying, various authentications methods, ...).